@@ -5,8 +5,8 @@ from requests.auth import HTTPBasicAuth
 from importlib import import_module
 
 from slai.modules.parameters import from_config
-from slai.config import get_api_base_url
-from slai.modules.runtime import detect_runtime, detect_credentials
+from slai.config import get_api_base_urls
+from slai.modules.runtime import detect_credentials
 
 
 REQUESTS_TIMEOUT = 15
@@ -25,16 +25,15 @@ def get_identity_client(*, client_id=None, client_secret=None, key_type=None):
 
 
 class IdentityClient:
-    BASE_URL = get_api_base_url()
+    BACKEND_BASE_URL, _ = get_api_base_urls()
 
     def __init__(self, client_id=None, client_secret=None, key_type=None):
-        self.runtime = detect_runtime()
         self.credentials_loaded = False
         self.key_type = key_type
 
         if not client_id or not client_secret:
             try:
-                self.credentials = detect_credentials(runtime=self.runtime)
+                self.credentials = detect_credentials()
                 self.client_id = self.credentials["client_id"]
                 self.client_secret = self.credentials["client_secret"]
                 self.credentials_loaded = True
@@ -47,19 +46,6 @@ class IdentityClient:
 
             self.credentials_loaded = True
 
-    def validate_notebook_auth_token(self, *, token):
-        body = {"action": "retrieve", "token": token}
-
-        res = requests.post(
-            f"{self.BASE_URL}/app/notebook-auth",
-            auth=None,
-            headers={},
-            json=body,
-            timeout=REQUESTS_TIMEOUT,
-        )
-        res.raise_for_status()
-        return res.json()
-
     def get_user(self):
         if not self.credentials_loaded:
             raise NoCredentialsFound("no_credentials_loaded")
@@ -67,7 +53,7 @@ class IdentityClient:
         body = {"action": "retrieve"}
 
         res = requests.post(
-            f"{self.BASE_URL}/cli/user",
+            f"{self.BACKEND_BASE_URL}/cli/user",
             auth=HTTPBasicAuth(self.client_id, self.client_secret),
             headers={},
             json=body,
@@ -85,7 +71,7 @@ class IdentityClient:
             body["key_type"] = self.key_type
 
         res = requests.post(
-            f"{self.BASE_URL}/cli/validate-credentials",
+            f"{self.BACKEND_BASE_URL}/cli/validate-credentials",
             auth=HTTPBasicAuth(self.client_id, self.client_secret),
             headers={},
             json=body,
